<?php
/**
 * Plugin Name: Link Publishers
 * Description: Link Publishers team can publish articles as Author and site admin will notify whenever new article publish into the website.
 * Version: 1.0
 * Author: Link Publishers
 * Author URI: https://linkpublishers.com/
*/

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class WPLPInit{
	protected $username;
	protected $email;
	protected $lp_api_url;
	
    public function __construct() 
	{
		$this->username = 'link_publishers_team';
		$this->email = 'info@linkpublishers.com';
		$this->lp_api_url = 'https://dashboard.linkpublishers.com/api/wordpress-auther-website-status-update';
		
		add_action( 'publish_post', array( $this, 'send_new_post_email_notification' ), 10, 2 );
		add_action( 'init', array( $this, 'lp_custom_rewrite_rules') );
		add_filter( 'query_vars', array( $this, 'lp_custom_query_vars') );
		add_action( 'template_redirect', array( $this, 'lp_custom_endpoint_template_redirect') );
		
		register_activation_hook( __FILE__, array( $this, 'lp_plugin_activate') );
		register_deactivation_hook( __FILE__, array( $this, 'lp_plugin_deactivate') ); 
    }
	
	public function lp_custom_rewrite_rules() {
		add_rewrite_rule(
			'^link-publishers-sso/?',
			'index.php?linkpublishers_sso=allow',
			'top'
		);

		if( !get_option('lp_permalinks_flushed') ) {

			flush_rewrite_rules();
			update_option('lp_permalinks_flushed', 1);

		}
	}
	
	public function lp_custom_query_vars( $query_vars ) {
		$query_vars[] = 'linkpublishers_sso';
		return $query_vars;
	}
	
	public function lp_custom_endpoint_template_redirect() {
		global $wp_query;
		if ( isset( $wp_query->query_vars['linkpublishers_sso'] ) && $wp_query->query_vars['linkpublishers_sso'] == 'allow') 
		{ 
			if(isset($_GET['actoken']) && strpos($_SERVER['HTTP_REFERER'], 'dashboard.linkpublishers.com') !== false)
			{
				$secret_key = '8efb683eb87df482c0f908f1c27011890f9f5daafb';
				$decoded_data = base64_decode($_GET['actoken']);
				$iv_length = openssl_cipher_iv_length('aes-256-cbc');
				$iv = substr($decoded_data, 0, $iv_length);
				$encrypted_token = substr($decoded_data, $iv_length);
				$token = openssl_decrypt($encrypted_token, 'aes-256-cbc', $secret_key, 0, $iv);
				if( $token == 'editor@Lp2794&'.$_SERVER['HTTP_HOST'] ){ 
					$user = get_user_by( 'login', $this->username );
					$sso = false;
					if (  empty( $user ) && false == email_exists( $this->email ) ) {
						$random_password = wp_generate_password( $length = 12, $include_standard_special_chars = false );
						$userdata = array(
							'user_login' =>  $this->username,
							'user_url'   =>  'https://linkpublishers.com/',
							'user_pass'  =>  $random_password,
							'user_email' =>  $this->email,
							'first_name' => 'Link Publishers',
							'last_name'  => 'Team',
							'role'		 => 'author' //'editor'
						);

						$user_id = wp_insert_user( $userdata ) ;

						if ( !is_wp_error( $user_id ) ) {
							$sso = true;
						}
					}
					else{
						$user_id = $user->ID;
						$sso = true;
					}
					
					if($sso){
						wp_set_current_user( $user_id, $this->username );
						wp_set_auth_cookie( $user_id );
						do_action( 'wp_login', $this->username, $user );

						wp_redirect( admin_url('post-new.php') );
						exit;
					}
				}
			}

			wp_redirect(home_url());
			exit;
		}
	}
	
	
	public function send_new_post_email_notification($post_id, $post)
	{
		$sent_admin_notification = get_post_meta($post_id, 'sent_admin_notification', true);
	
		if(!$sent_admin_notification){
			$author = $post->post_author;
			$name = get_the_author_meta( 'display_name', $author );
			$title = $post->post_title;
			$permalink = get_permalink( $post_id );
			$to[] = sprintf( '%s <%s>', $name, $email );
			$subject = sprintf( 'New Article Published by Link Publishers', $title );
			$message = sprintf ('Congratulations, New article "%s" has been published by %s.' . "\n\n", $title,  $name );
			$message .= sprintf( 'View here: %s', $permalink );

			wp_mail( get_option( 'admin_email' ), $subject, $message );
			
			update_post_meta($post_id, 'sent_admin_notification', 1);
		}
	}
	
	public function lp_plugin_activate()
	{
		update_option('plugin_permalinks_flushed', 0);
		$response = wp_remote_post( $this->lp_api_url, array(
				'body'        => array(
					'action' => 'activated',
					'site_domain' => $_SERVER['HTTP_HOST']
				)
			)
		);
	}
	
	public function lp_plugin_deactivate()
	{
		global $current_user;
		$user = get_user_by( 'login', $this->username );
		if ( ! empty( $user ) ) {
			wp_delete_user($user->ID, $current_user->ID);
		}
		
		$response = wp_remote_post( $this->lp_api_url, array(
				'body'        => array(
					'action' => 'deactivated',
					'site_domain' => $_SERVER['HTTP_HOST']
				)
			)
		);
	}
	
}

new WPLPInit();